@@ -440,6 +440,63 @@ dispatch_event (saver_info *si, XEvent *event)
 }
 
 
+static void
+swallow_unlock_typeahead_events (saver_info *si, XEvent *e)
+{
+  XEvent event;
+  char buf [100];
+  int i = 0;
+
+  memset (buf, 0, sizeof(buf));
+
+  event = *e;
+
+  do
+    {
+      if (event.xany.type == KeyPress)
+        {
+          char s[2];
+          int size = XLookupString (&event, s, 1, 0, 0);
+          if (size != 1) continue;
+          switch (*s)
+            {
+            case '\010': case '\177':			/* Backspace */
+              if (i > 0) i--;
+              break;
+            case '\025': case '\030':			/* Erase line */
+            case '\012': case '\015':			/* Enter */
+              i = 0;
+              break;
+            case '\040':				/* Space */
+              if (i == 0)
+                break;  /* ignore space at beginning of line */
+              /* else, fall through */
+            default:
+              buf [i++] = *s;
+              break;
+            }
+        }
+
+    } while (i < sizeof(buf)-1 &&
+             XCheckMaskEvent (si->dpy, KeyPressMask, &event));
+
+  buf[i] = 0;
+
+  if (si->unlock_typeahead)
+    {
+      memset (si->unlock_typeahead, 0, strlen(si->unlock_typeahead));
+      free (si->unlock_typeahead);
+    }
+
+  if (i > 0)
+    si->unlock_typeahead = strdup (buf);
+  else
+    si->unlock_typeahead = 0;
+
+  memset (buf, 0, sizeof(buf));
+}
+
+
 /* methods of detecting idleness:
 
       explicitly informed by SGI SCREEN_SAVER server event;
@@ -752,8 +809,13 @@ sleep_until_idle (saver_info *si, Bool until_idle_p)
      doesn't exhibit itself without an extension, because in that case,
      there's only one event generated by user activity, not two.)
    */
-  XCheckMaskEvent (si->dpy, (KeyPressMask|ButtonPressMask|PointerMotionMask),
-		   &event);
+  if (!until_idle_p && si->locked_p)
+    swallow_unlock_typeahead_events (si, &event);
+  else
+    while (XCheckMaskEvent (si->dpy,
+                            (KeyPressMask|ButtonPressMask|PointerMotionMask),
+                     &event))
+      ;
 
 
   if (si->check_pointer_timer_id)
